#!/bin/sh

# SOURCE: http://ftp.gnome.org/pub/GNOME/sources/evince/
# MAINTAINER: Sebastian Jauch
# Default desktopfile doesn't show up in menu
# place "evince.desktop" in CWD to include

CWD=`pwd`
PKG=/tmp/package-evince

VERSION=2.24.2
ARCH=i486
BUILD=54.2

SLKCFLAGS="-O2 -march=i486 -mtune=i686"

rm -rf $PKG
mkdir -p $PKG
cd /tmp
rm -rf evince-$VERSION
tar xjvf $CWD/evince-$VERSION.tar.bz2
cd evince-$VERSION
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 664 -exec chmod 644 {} \;

CFLAGS="$SLKCFLAGS" \
./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --enable-djvu \
  --enable-impress \
  --localstatedir=/var \
  --enable-pixbuf \
  --enable-nautilus \
  --mandir=/usr/man \
  --with-omf-dir=/usr/share/omf \
  --disable-schemas-install \
  --with-gconf-source="xml::/etc/gconf/gconf.xml.defaults" \
  --with-print=gtk

make
cp -u /usr/share/omf/evince/evince-* $PKG/usr/share/omf/evince/evince-*
make install DESTDIR=$PKG

( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#zip man pages
gzip -9 $PKG/usr/man/*/*

mkdir -p $PKG/usr/src/evince-$VERSION
cp $CWD/build-evince.sh $PKG/usr/src/evince-$VERSION

mkdir -p $PKG/usr/doc/evince-$VERSION
cp -a AUTHORS ChangeLog COPYING MAINTAINERS NEWS README TODO $PKG/usr/doc/evince-$VERSION

#add needed icons for toolbar-editor
cd $PKG
if [ -f $CWD/evince-icons.tar.bz2 ]; then
   (cd $PKG/usr/share/evince/icons/hicolor/ ; tar xvjf $CWD/evince-icons.tar.bz2 )
fi

chown -R root.root $PKG/usr/share/

mkdir -p $PKG/usr/share/applications/
cat <<"EOF" > $PKG/usr/share/applications/evince.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Evince
Name[bg]=Евинце
Name[el]=Εβίνζε
Name[fa]=نمایشگر نوشتار
Name[gu]=દસ્તાવેજ દર્શક
Name[he]=מציג מסמכים
Name[hi]=लेखपत्र प्रदर्शक
Name[mk]=Евинце
Name[ne]=कागजात दृश्यक
Name[pa]=ਦਸਤਾਵੇਜ਼ ਦਰਸ਼ਕ
Name[ru]=Евинце
Name[sr]=Евинце
Name[th]=โปรแกรมดูเอกสาร
Name[uk]=Евинце
GenericName=Document Viewer
GenericName[be]=Глядач дакумэнтаў
GenericName[bg]=Преглед на документи
GenericName[bn]=ডকুমেন্ট প্রদর্শক
GenericName[br]=Lenner dielloù
GenericName[ca]=Visualitzador de documents
GenericName[cs]=Prohlížeč dokumentů
GenericName[cy]=Gwelydd Dogfennau
GenericName[da]=Dokumentfremviser
GenericName[de]=Dokumentenbetrachter
GenericName[dz]=ཡིག་ཆ་མཐོང་བྱེད།
GenericName[el]=Προβολέας Εγγράφου
GenericName[en_CA]=Document Viewer
GenericName[en_GB]=Document Viewer
GenericName[es]=Visor de documentos
GenericName[et]=Dokumendivaatur
GenericName[eu]=Dokumentu ikustailea
GenericName[fa]=نمایشگر نوشتار
GenericName[fi]=Asiakirjakatselin
GenericName[fr]=Visionneur de documents
GenericName[gl]=Visor de documentos
GenericName[gu]=દસ્તાવેજ દર્શક
GenericName[he]=מציג מסמכים
GenericName[hi]=लेखपत्र प्रदर्शक
GenericName[hu]=Dokumentum-megjelenítő
GenericName[id]=Pembaca Dokumen
GenericName[it]=Visualizzatore documenti
GenericName[ja]=文書ビューア
GenericName[ka]=დოკუმენტების მნახველი
GenericName[ko]=문서 보기
GenericName[lt]=Dokumentų peržiūros programa
GenericName[lv]=Dokumenta skatītājs
GenericName[mk]=Прегледувач за документи
GenericName[nb]=Dokumentvisning
GenericName[ne]=कागजात दृश्यक
GenericName[nl]=Documentenviewer
GenericName[nn]=Dokumentframsynar
GenericName[pa]=ਦਸਤਾਵੇਜ਼ ਦਰਸ਼ਕ
GenericName[pl]=Przeglądarka dokumentów
GenericName[pt]=Visualizador de Documento
GenericName[pt_BR]=Visualizador de Documentos
GenericName[ro]=Vizualizare document
GenericName[ru]=Просмотр документов
GenericName[sk]=Prehliadač dokumentov
GenericName[sq]=Shikues dokumentesh
GenericName[sr]=Прегледач докумената
GenericName[sr@Latn]=Pregledač dokumenata
GenericName[sv]=Dokumentvisare
GenericName[th]=โปรแกรมดูเอกสาร
GenericName[tr]=Belge Görüntüleyici
GenericName[uk]=Перегляд документів
GenericName[vi]=Bộ xem tài liệu
GenericName[wa]=Håyneu di documints
GenericName[zh_CN]=文档查看器
GenericName[zh_HK]=文件檢視器
GenericName[zh_TW]=文件檢視器
Comment=View multipage documents
Comment[be]=Дазваляе праглядаць шматлікія дакумэнты
Comment[bg]=Преглед на документи с много страници
Comment[bn]=বহুপৃষ্ঠাব্যাপী ডকুমেন্ট দেখুন
Comment[br]=Gwelout teulioù gant meur a bajenn
Comment[ca]=Visualitzeu documents multi-pàgina
Comment[cs]=Zobrazovat dokumenty s více stranami
Comment[cy]=Gweld dogfennau aml-dudalen
Comment[da]=Vis dokumenter med flere sider
Comment[de]=Mehrseitige Dokumente anzeigen
Comment[dz]=སྣ་མང་ཤོག་ལེབ་ཡིག་ཆ་ཚུ་སྟོན།
Comment[el]=Προβολή εγγράφων πολλαπλών σελίδων
Comment[en_CA]=View multipage documents
Comment[en_GB]=View multi-page documents
Comment[es]=Ver documentos multipágina
Comment[et]=Mitmeleheküljeliste dokumentide vaatamine
Comment[eu]=Ikusi orri anitzeko dokumentuak
Comment[fa]=نمایش چندین نوشتار
Comment[fi]=Katsele monisivuisia asiakirjoja
Comment[fr]=Affiche les documents multipages
Comment[gl]=Ver documentos multipáxina
Comment[gu]=ઘણા દસ્તાવેજો જુઓ
Comment[he]=הצג מסמכים מרובי דפים
Comment[hi]=देखें बहुपेज दस्तावेज
Comment[hu]=Többoldalas dokumentumok megjelenítése
Comment[id]=Baca dokumen
Comment[it]=Visualizza documenti multi pagina
Comment[ja]=複数ページの文書を表示します
Comment[ko]=다중 페이지 문서를 봅니다
Comment[lt]=Peržiūrėti kelių puslapių dokumentams
Comment[lv]=Skatīt virākus dokumentus
Comment[mk]=Види повеќе документи
Comment[nb]=Vis dokumenter
Comment[ne]=वहुपृष्ठ कागजात दृश्य गर्नुहोस
Comment[nl]=Documenten met meerdere pagina's weergeven
Comment[nn]=Vis fleirsidedokument
Comment[pa]=ਬਹੁ-ਸਫ਼ੇ ਦਸਤਾਵੇਜ਼ ਵੇਖੋ
Comment[pl]=Wyświetla wielostronnicowe dokumenty
Comment[pt]=Visualizar documentos de múltiplas páginas
Comment[pt_BR]=Visualize documentos multipágina
Comment[ro]=Vizualizarea în mai multe pagini
Comment[ru]=Просмотр многостраничных документов
Comment[sk]=Zobraziť viacstranové dokumenty
Comment[sq]=Shiko dokumentë shumfaqësh
Comment[sr]=Прегледајте вишестраничне документе
Comment[sr@Latn]=Pregledajte višestranične dokumente
Comment[sv]=Visa dokument med flera sidor
Comment[th]=ดูเอกสารแบบหลายหน้า
Comment[tr]=Çok sayfalı belgeleri göster
Comment[uk]=Перегляд багатосторінкових документів
Comment[vi]=Xem tài liệu đa trang
Comment[wa]=Vey des documints multi-pådje
Comment[zh_CN]=查看多页文档
Comment[zh_HK]=閱讀文件
Comment[zh_TW]=閱讀文件
TryExec=evince
Exec=evince %U
StartupNotify=true
Type=Application
Icon=evince
X-GNOME-DocPath=
X-GNOME-Bugzilla-Bugzilla=GNOME
X-GNOME-Bugzilla-Product=evince
X-GNOME-Bugzilla-Component=General
Categories=Application;Graphics;Viewer;
MimeType=application/pdf;application/postscript;application/x-gzpostscript;image/tiff;image/x.djvu;
EOF

# redundant scrollkeeper
if [ -d ${PKG}/var/scrollkeeper ]; then
	rm -r ${PKG}/var/scrollkeeper
fi
if [ -d ${PKG}/var/lib/scrollkeeper ]; then
	rm -r ${PKG}/var/lib/scrollkeeper
fi

mkdir -p $PKG/install

cat <<"EOF" > $PKG/install/doinst.sh
# Update the scrollkeeper database (Remove stale pieces)
if [ -x usr/bin/scrollkeeper-update ]; then
        usr/bin/scrollkeeper-update > /dev/null 2>&1
fi
EOF

# Install gconf Schemas

export GCONF_CONFIG_SOURCE="xml::$PKG/etc/gconf/gconf.xml.defaults"
if [ -d $PKG/etc/gconf/schemas ]; then
     install -v -d -m755 $PKG/etc/gconf/gconf.xml.defaults
     SCHEMAS=$PKG/etc/gconf/schemas
     for schema in $SCHEMAS/*.schemas; do
         gconftool-2 --makefile-install-rule $schema
     done
     # Reset / Verify correct permissions
     ( cd $PKG/etc/gconf ; find . -type d -exec chmod 755 {} \; )
     ( cd $PKG/etc/gconf ; find . -type f -exec chmod 644 {} \; )
fi



#
# make a slack-desc file
#
cat <<"EOF" > $PKG/install/slack-desc
      |-----handy-ruler-----------------------------------------------|
evince: evince  (Document viewer)
evince:
evince: Evince is a simple document viewer, it can handle postcript,
evince: pdf and tiff-files, it requires poppler.
evince:
evince:
evince:
evince:
evince:
evince:
evince:
EOF

cd $PKG
makepkg -l y -c n ../evince-$VERSION-$ARCH-$BUILD.tgz
cd ..
md5sum evince-$VERSION-$ARCH-$BUILD.tgz > evince-$VERSION-$ARCH-$BUILD.md5
echo " .. Building dependency file .. "
requiredbuilder -z evince-$VERSION-$ARCH-$BUILD.tgz > evince-$VERSION-$ARCH-$BUILD.dep
n_thumbn=$(tar tvzf evince-$VERSION-$ARCH-$BUILD.tgz|grep thumbnailer|wc -l)
if [ $n_thumbn -lt 1 ]; then
    echo "Evince-Thumbnailer is missing!"
fi
